catch_panic_or

Function catch_panic_or 

pub fn catch_panic_or<T>(on_panic: T, f: impl FnOnce() -> T) -> T
Like catch_panic, for callbacks whose C signature returns a value other than an error code (e.g. a boolean): on_panic is returned to C.

Like catch_panic, it runs f in a new level of igraph’s finally stack.