has_pending_panic

Function has_pending_panic 

pub fn has_pending_panic() -> bool
Whether a panic caught by catch_panic is waiting to be resumed on the calling thread (by the next check or resume_panic).

Trampolines of callbacks that igraph keeps calling after an error can use it to skip the user code once it has panicked.